diff --git a/drivers/mtd/spi-nor/controllers/aspeed-smc.c b/drivers/mtd/spi-nor/controllers/aspeed-smc.c
index e5f2108956b5..bb7cc41355e6 100644
--- a/drivers/mtd/spi-nor/controllers/aspeed-smc.c
+++ b/drivers/mtd/spi-nor/controllers/aspeed-smc.c
@@ -1262,10 +1262,6 @@ static int aspeed_smc_setup_flash(struct aspeed_smc_controller *controller,
 			break;
 		}
 
-		if (of_property_read_bool(child, "mx25l25635f-disable-dual-mode")) {
-			hwcaps.mask &= ~SNOR_HWCAPS_READ_1_1_2;
-		}
-
 		if (cs >= info->nce) {
 			dev_err(dev, "Chip select %d out of range.\n",
 				cs);
diff --git a/drivers/mtd/spi-nor/core.c b/drivers/mtd/spi-nor/core.c
index 06e1bf01fd92..a375d3ce1da3 100644
--- a/drivers/mtd/spi-nor/core.c
+++ b/drivers/mtd/spi-nor/core.c
@@ -1029,18 +1029,20 @@ static u8 spi_nor_convert_opcode(u8 opcode, const u8 table[][2], size_t size)
 u8 spi_nor_convert_3to4_read(u8 opcode)
 {
 	static const u8 spi_nor_3to4_read[][2] = {
-		{ SPINOR_OP_READ,	SPINOR_OP_READ_4B },
-		{ SPINOR_OP_READ_FAST,	SPINOR_OP_READ_FAST_4B },
-		{ SPINOR_OP_READ_1_1_2,	SPINOR_OP_READ_1_1_2_4B },
-		{ SPINOR_OP_READ_1_2_2,	SPINOR_OP_READ_1_2_2_4B },
-		{ SPINOR_OP_READ_1_1_4,	SPINOR_OP_READ_1_1_4_4B },
-		{ SPINOR_OP_READ_1_4_4,	SPINOR_OP_READ_1_4_4_4B },
-		{ SPINOR_OP_READ_1_1_8,	SPINOR_OP_READ_1_1_8_4B },
-		{ SPINOR_OP_READ_1_8_8,	SPINOR_OP_READ_1_8_8_4B },
-
-		{ SPINOR_OP_READ_1_1_1_DTR,	SPINOR_OP_READ_1_1_1_DTR_4B },
-		{ SPINOR_OP_READ_1_2_2_DTR,	SPINOR_OP_READ_1_2_2_DTR_4B },
-		{ SPINOR_OP_READ_1_4_4_DTR,	SPINOR_OP_READ_1_4_4_DTR_4B },
+		{ SPINOR_OP_READ, SPINOR_OP_READ_4B },
+		{ SPINOR_OP_READ_FAST, SPINOR_OP_READ_FAST_4B },
+		{ SPINOR_OP_READ_1_1_2, SPINOR_OP_READ_1_1_2_4B },
+		{ SPINOR_OP_READ_1_2_2, SPINOR_OP_READ_1_2_2_4B },
+		{ SPINOR_OP_READ_1_1_4, SPINOR_OP_READ_1_1_4_4B },
+		{ SPINOR_OP_READ_1_4_4, SPINOR_OP_READ_1_4_4_4B },
+		{ SPINOR_OP_READ_1_1_8, SPINOR_OP_READ_1_1_8_4B },
+		{ SPINOR_OP_READ_1_8_8, SPINOR_OP_READ_1_8_8_4B },
+
+		{ SPINOR_OP_READ_1_1_1_DTR, SPINOR_OP_READ_1_1_1_DTR_4B },
+		{ SPINOR_OP_READ_1_2_2_DTR, SPINOR_OP_READ_1_2_2_DTR_4B },
+		{ SPINOR_OP_READ_1_4_4_DTR, SPINOR_OP_READ_1_4_4_DTR_4B },
+
+		{ SPINOR_OP_READ_1_1_2_MX, SPINOR_OP_READ_1_1_2}
 	};
 
 	return spi_nor_convert_opcode(opcode, spi_nor_3to4_read,
diff --git a/drivers/mtd/spi-nor/macronix.c b/drivers/mtd/spi-nor/macronix.c
index ee376edbfa2c..d5c9a90ab36a 100644
--- a/drivers/mtd/spi-nor/macronix.c
+++ b/drivers/mtd/spi-nor/macronix.c
@@ -23,8 +23,11 @@ mx25l25635_post_bfpt_fixups(struct spi_nor *nor,
 	 * seems that the F version advertises support for Fast Read 4-4-4 in
 	 * its BFPT table.
 	 */
-	if (bfpt->dwords[BFPT_DWORD(5)] & BFPT_DWORD5_FAST_READ_4_4_4)
+	if (bfpt->dwords[BFPT_DWORD(5)] & BFPT_DWORD5_FAST_READ_4_4_4) {
 		nor->flags |= SNOR_F_4B_OPCODES;
+		dev_info(nor->dev, "DEBUG: Applying mx25l25635_post_bfpt_fixups\n");
+		nor->read_opcode = SPINOR_OP_READ_1_1_2_MX;
+	}
 
 	return 0;
 }
diff --git a/include/linux/mtd/spi-nor.h b/include/linux/mtd/spi-nor.h
index 60bac2c0ec45..d998433df7af 100644
--- a/include/linux/mtd/spi-nor.h
+++ b/include/linux/mtd/spi-nor.h
@@ -79,6 +79,8 @@
 #define SPINOR_OP_READ_1_2_2_DTR_4B	0xbe
 #define SPINOR_OP_READ_1_4_4_DTR_4B	0xee
 
+#define SPINOR_OP_READ_1_1_2_MX     0xef
+
 /* Used for SST flashes only. */
 #define SPINOR_OP_BP		0x02	/* Byte program */
 #define SPINOR_OP_AAI_WP	0xad	/* Auto address increment word program */
-- 
2.29.2

